pub struct Ellipses;Trait Implementations
sourceimpl Ord for Ellipses
impl Ord for Ellipses
sourceimpl PartialOrd<Ellipses> for Ellipses
impl PartialOrd<Ellipses> for Ellipses
sourcefn partial_cmp(&self, other: &Ellipses) -> Option<Ordering>
fn partial_cmp(&self, other: &Ellipses) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for Ellipses
impl StructuralEq for Ellipses
impl StructuralPartialEq for Ellipses